Download PySkein — PySkein v0.3 documentation

### Navigation

- index
- previous |
- PySkein v0.3 documentation »

# Download PySkein

New in version 0.3:
  - Threefish block decryption
  - Demo scripts `skeinsum.py` and `threefish.py`
Download:
  - Source distribution: pyskein-0.3.tar.gz (sig)
  - Windows Installer: pyskein-0.3.win32-py3.0.exe (sig)

## Previous versions

- PySkein 0.2
    - New in this version:
        - Support for message authentication codes
        - Threefish block encryption (but no decryption)
        - Fixed one or two reference leaks
    - Download:
        - Source distribution: pyskein-0.2.tar.gz (sig)
        - Windows Installer: pyskein-0.2.win32-py3.0.exe (sig)
- PySkein 0.1
    - New in this version:
        - Skein-256, Skein-512, and Skein-1024 hashing
    - Download:
        - Source distribution: pyskein-0.1.tar.gz (sig)

### Navigation

- index
- previous |
- PySkein v0.3 documentation »